### Name: reduce
### Title: Boolean miniziation for csQCA, mvQCA and fsQCA
### Aliases: reduce reduce.truthTable reduce.default print.QCA summary.QCA
###   [.QCA


### ** Examples

## Not run: 
##D data(Osa,package="QCA") ## QCA package is required to run this example
##D ## the same as examples of QCA:::qmcc
##D conditions <- c("DYNA","ACCES","INFLU","ELITE","SOCIAL")
##D reduce(Osa,"OUT",conditions,explain="positive",remaind="exclude")
##D reduce(Osa,"OUT",conditions,explain="positive",contradictions="positive",remaind="include")
##D ans <- reduce(Osa,"OUT",conditions,explain="positive",contradictions="negative",remaind="include")
##D simplifyingAssumption(ans) ## or SA(ans)
##D reduce(Osa,"OUT",conditions,explain="negative",contradictions="negative",remaind="include")
##D 
##D ## Results of Osa and Corduneanu-Huci (2003)
##D reduce(Osa,"OUT",conditions,explain="pos",contrad="neg",remaind="exclude") # table 1 in page 617
##D reduce(Osa,"OUT",conditions,explain="neg",contrad="pos",remaind="exclude") # table 2 of page 621
##D reduce(Osa,"OUT",conditions,explain="positive",contradictions="pos",remaind="incl") # maximum reduction in page 623
##D reduce(Osa,"OUT",conditions[1:4],explain="pos",contradictions="neg",remaind="excl") # Appendix 2 in page 629
## End(Not run)

## csQCA, mvQCA and fsQCA examples are from "Configuraional comparative Methods"
## csQCA
conditions <- c("GNPCAP", "URBANIZA", "LITERACY", "INDLAB", "GOVSTAB")
reduce(Lipset_cs,"SURVIVAL",conditions,explain="positive",remainder="exclude",case="CASEID")
## Formula 1 in Rihoux and De Meur(2009:57)
reduce(Lipset_cs,"SURVIVAL",conditions,explain="negative",remainder="exclude",case="CASEID")
## Formula 3 in Rihoux and De Meur(2009:59)
ans1 <- reduce(Lipset_cs,"SURVIVAL",conditions,explain="positive",remainder="include",case="CASEID")
print(ans1)
## Formula 4 in Rihoux and De Meur(2009:60)
SA(ans1) ## 5 simplifying assumptions in p61
ans0 <- reduce(Lipset_cs,"SURVIVAL",conditions,explain="negative",remainder="include",case="CASEID")
print(ans0)
## Formula 5 in Rihoux and De Meur(2009:61)
SA(ans0) ## 18 simplifying assumptions

## mvQCA
conditions <- c("GNPCAP", "URBANIZA", "LITERACY", "INDLAB")
reduce(Lipset_mv,"SURVIVAL",conditions,explain="positive",remainder="exclude",case="CASEID",nlevels=c(3,2,2,2))
## formula 1 Cronqvist and Berg-Schlosser(2009:80)
ans1 <-
reduce(Lipset_mv,"SURVIVAL",conditions,explain="positive",remainder="include",case="CASEID",nlevels=c(3,2,2,2))
print(ans1)
## formula 2 in Cronqvist and Berg-Schlosser(2009:81)
SA(ans1) ## 9 SAs (see end note 7)
reduce(Lipset_mv,"SURVIVAL",conditions,explain="negative",remainder="exclude",case="CASEID",nlevels=c(3,2,2,2))
## formula 3 in Cronqvist and Berg-Schlosser(2009:81)
ans0 <-
reduce(Lipset_mv,"SURVIVAL",conditions,explain="negative",remainder="include",contrad="positive",case="CASEID",nlevels=c(3,2,2,2))
print(ans0)
## formula 4 in Cronqvist and Berg-Schlosser(2009:81)
SA(ans0) ## 7 SAs (see end note 9)

## fsQCA
conditions <- c("Developed.FZ","Urban.FZ","Literate.FZ","Industrial.FZ", "Stable.FZ")
reduce(mydata=Lipset_fs,"Survived.FZ",conditions,explain="positive",remaind="exclude",prepro="fs",consistency=0.7)
## Formula 1 in Ragin (2009:112)
reduce(mydata=Lipset_fs,"Survived.FZ",conditions,explain="positive",remaind="include",prepro="fs",consistency=0.7)
## Formula 2 in Ragin (2009:114)
reduce(mydata=Lipset_fs,"Survived.FZ",conditions,explain="negative",remaind="exclude",prepro="fs",consistency=0.7)
## Formula 5 in Ragin (2009:115)
reduce(mydata=Lipset_fs,"Survived.FZ",conditions,explain="negative",remaind="include",prepro="fs",consistency=0.7)
## Formula 6 in Ragin (2009:117)



